@@ -15,8 +15,9 @@
 """
 from grokcore.component import *
 
-from grokcore.security.components import Permission, Public
-from grokcore.security.directive import require
+from grokcore.security.components import Permission, Role
+from grokcore.security.components import Public
+from grokcore.security.directive import require, permissions
 
 # Import this module so that it's available as soon as you import the
 # 'grokcore.security' package.  Useful for tests and interpreter examples.
