@@ -18,6 +18,8 @@ from zope.interface import Interface, Attribute
 class IBaseClasses(Interface):
     Permission = Attribute("Base class for permissions.")
 
+    Role = Attribute("Base class for roles.")
+
 
 class IDirectives(Interface):
 
@@ -30,6 +32,10 @@ class IDirectives(Interface):
         grok.require can be used as a class-level directive or as a
         method decorator."""
 
+    def permissions(permissions):
+        """Specify the permissions that comprise a role.
+        """
+
 
 class IGrokcoreSecurityAPI(IBaseClasses, IDirectives):
     Public = Attribute("Permission identifier to denote public access.")
